@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = "2.021";
+our $VERSION = "2.022";
 # ABSTRACT: time tracking for impatient and lazy command line lovers
 
 use App::TimeTracker::Data::Task;
@@ -196,6 +196,14 @@ sub find_task_files {
     if ( $args->{projects} ) {
         $projects = join( '|', map { s/-/./g; $_ } @{ $args->{projects} } );
     }
+
+    my $children;
+    if ($args->{parent}) {
+        my @kids = $args->{parent};
+        $self->all_childs_of($args->{parent},\@kids);
+        $children = join( '|', map { s/-/./g; $_ } @kids );
+    }
+
     my $tags;
     if ( $args->{tags} ) {
         $tags = join( '|', @{ $args->{tags} } );
@@ -221,6 +229,10 @@ sub find_task_files {
             next unless ( $name =~ m/$projects/i );
         }
 
+        if ($children) {
+            next unless ( $name =~ m/$children/i );
+        }
+
         if ($tags) {
             my $raw_content = $file->slurp;
             next unless $raw_content =~ /$tags/i;
@@ -241,7 +253,7 @@ sub project_tree {
     my %tree;
     my $depth;
     while ( my ( $project, $location ) = each %$projects ) {
-        $tree{$project} //= { parent => undef, childs => {} };
+        $tree{$project} //= { parent => undef, children => {} };
         # check config file for parent
         if ( -e $location ) {
             my $this_config = $decoder->decode(
@@ -264,6 +276,22 @@ sub project_tree {
     return \%tree;
 }
 
+sub all_childs_of {
+    my ($self, $parent, $collector) = @_;
+
+    my $tree = $self->project_tree;
+    my $this = $tree->{$parent};
+
+    my @kids = keys %{$this->{children}};
+
+    if (@kids) {
+        push(@$collector, @kids);
+        foreach my $kid (@kids) {
+            $self->all_childs_of($kid, $collector);
+        }
+    }
+}
+
 1;
 
 __END__
@@ -278,7 +306,7 @@ App::TimeTracker - time tracking for impatient and lazy command line lovers
 
 =head1 VERSION
 
-version 2.021
+version 2.022
 
 =head1 SYNOPSIS
 
@@ -288,7 +316,7 @@ Backend for the C<tracker> command. See L<tracker> and/or C<perldoc tracker> for
 
 Maros Kollar, Klaus Ita, Yanick Champoux, Lukas Rampa, David Schmidt,
 Michael Kröll, Thomas Sibley, Nelo Onyiah, Jozef Kutej, Roland Lammel,
-Ruslan Zakirov, Kartik Thakore, Tokuhiro Matsuno
+Ruslan Zakirov, Kartik Thakore, Tokuhiro Matsuno, Paul Cochrane, David Provost
 
 =head1 AUTHOR
 
